package com.yanzhu.manage.mapper;

import java.util.List;
import com.yanzhu.manage.domain.BusExamUserResult;

/**
 * 用户试卷结果Mapper接口
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
public interface BusExamUserResultMapper 
{
    /**
     * 查询用户试卷结果
     * 
     * @param examUserId 用户试卷结果主键
     * @return 用户试卷结果
     */
    public BusExamUserResult selectBusExamUserResultByExamUserId(Long examUserId);

    /**
     * 查询用户试卷结果列表
     * 
     * @param busExamUserResult 用户试卷结果
     * @return 用户试卷结果集合
     */
    public List<BusExamUserResult> selectBusExamUserResultList(BusExamUserResult busExamUserResult);

    /**
     * 新增用户试卷结果
     * 
     * @param busExamUserResult 用户试卷结果
     * @return 结果
     */
    public int insertBusExamUserResult(BusExamUserResult busExamUserResult);

    /**
     * 修改用户试卷结果
     * 
     * @param busExamUserResult 用户试卷结果
     * @return 结果
     */
    public int updateBusExamUserResult(BusExamUserResult busExamUserResult);

    /**
     * 删除用户试卷结果
     * 
     * @param examUserId 用户试卷结果主键
     * @return 结果
     */
    public int deleteBusExamUserResultByExamUserId(Long examUserId);

    /**
     * 批量删除用户试卷结果
     * 
     * @param examUserIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusExamUserResultByExamUserIds(Long[] examUserIds);
}
